%define srcname docutils
%define enable_tests 1

Name:		python-%{srcname}
Summary:	Python Documentation Utilities
Version:	0.12
Release:	%mkrel 1
URL:		http://docutils.sourceforge.net/
License:	Public Domain and BSD and Python and GPLv3+
Group:		Development/Python
#Source:		http://downloads.sourceforge.net/project/docutils/docutils/%{version}/%{srcname}-%{version}.tar.gz
# Sometimes we need snapshots.  Instructions below:
# svn co -r 7747 https://docutils.svn.sourceforge.net/svnroot/docutils/trunk/docutils
# cd docutils
# python setup.py sdist
# The tarball is in dist/docutils-VERSION.tar.gz
Source:		%{srcname}-%{version}.tar.xz

BuildArch:	noarch
BuildRequires:	pkgconfig(python)
BuildRequires:	emacs
BuildRequires:	python-setuptools
Recommends:	python-imaging

%description
The Docutils project specifies a plaintext markup language, reStructuredText,
which is easy to read and quick to write.  The project includes a python
library to parse rST files and transform them into other useful formats such
as HTML, XML, and TeX as well as commandline tools that give the enduser
access to this functionality.

Currently, the library supports parsing rST that is in standalone files and
PEPs (Python Enhancement Proposals).  Work is underway to parse rST from
Python inline documentation modules and packages.

%package -n python3-%{srcname}
Summary:	System for processing plaintext documentation for python3
Group:		Development/Python
BuildRequires:	pkgconfig(python3)
BuildRequires:	python3-setuptools
BuildRequires:  python-tools
Recommends:	python3-imaging

%description -n python3-%{srcname}
The Docutils project specifies a plaintext markup language, reStructuredText,
which is easy to read and quick to write.  The project includes a python
library to parse rST files and transform them into other useful formats such
as HTML, XML, and TeX as well as commandline tools that give the enduser
access to this functionality.

Currently, the library supports parsing rST that is in standalone files and
PEPs (Python Enhancement Proposals).  Work is underway to parse rST from
Python inline documentation modules and packages.

This package contains the module, ported to run under python3.

%prep
%setup -q -n %{srcname}-%{version}

# Remove shebang from library files
for file in docutils/utils/{code_analyzer.py,punctuation_chars.py,error_reporting.py} docutils/utils/math/{latex2mathml.py,math2html.py} docutils/writers/xetex/__init__.py; do
sed -i -e '/#! *\/usr\/bin\/.*/{1D}' $file
done

cp -a . %{py3dir}

%build
CFLAGS="$RPM_OPT_FLAGS" %{__python} setup.py build

pushd %{py3dir}
CFLAGS="$RPM_OPT_FLAGS" %{__python3} setup.py build
popd

%install
# Must do the python3 install first because the scripts in /usr/bin are
# overwritten by setup.py install (and we want the python2 version to be the
# default for now).
pushd %{py3dir}
%{__python3} setup.py install --skip-build  --root=%{buildroot}

# docutils setup.py runs 2to3 on a copy of the tests and puts it in sitelib.
rm -rf %{buildroot}%{python3_sitelib}/test

# Flash file is used for testing docutils but shouldn't be in the installed package.
mv docs/user/rst/images/biohazard.swf ./biohazard.swf 
popd
rm -rf %{buildroot}%{_bindir}/*

%{__python} setup.py install --skip-build --root %{buildroot}

for file in %{buildroot}%_bindir/*.py; do
  mv $file %{buildroot}%_bindir/`basename $file .py`
done

# We want the licenses but don't need this build file
rm -f licenses/docutils.conf

# Flash file is used for testing docutils but shouldn't be in the installed package.
mv docs/user/rst/images/biohazard.swf ./biohazard.swf 

# Make emacs mode available:
emacs -batch -f batch-byte-compile tools/editors/emacs/rst.el
%__install -d -m 755 %{buildroot}%{_datadir}/emacs/site-lisp
%__install -D -m 644 tools/editors/emacs/rst.el* %{buildroot}%{_datadir}/emacs/site-lisp
%__rm -rf tools/editors/emacs

cat > ./rst.el << EOF
(autoload 'rst-mode "rst" "reStructuredText mode" t)
(add-to-list 'auto-mode-alist '("\\.rst$" . rst-mode))
EOF
emacs -batch -f batch-byte-compile rst.el
%__install -d -m 755 %{buildroot}%{_sysconfdir}/emacs/site-start.d
%__install -m 644 rst.el* %{buildroot}%{_sysconfdir}/emacs/site-start.d/


%check
%if %enable_tests
mv  biohazard.swf docs/user/rst/images/biohazard.swf
python test/alltests.py
rm docs/user/rst/images/biohazard.swf

pushd %{py3dir}
mv  biohazard.swf docs/user/rst/images/biohazard.swf
python3 test3/alltests.py
rm docs/user/rst/images/biohazard.swf
popd
%endif

%files
%doc BUGS.txt COPYING.txt FAQ.txt HISTORY.txt README.txt RELEASE-NOTES.txt   
%doc THANKS.txt licenses docs tools/editors 
%{_bindir}/*
%{python_sitelib}/*
%_datadir/emacs/site-lisp/*
%_sysconfdir/emacs/site-start.d/*

%files -n python3-%{srcname}
%doc BUGS.txt COPYING.txt FAQ.txt HISTORY.txt README.txt RELEASE-NOTES.txt 
%doc THANKS.txt licenses docs tools/editors
%{python3_sitelib}/*



%changelog
* Sat Jun 27 2015 gseaman <galen.seaman at comcast.net> 0.12-1gseaman2015
- rebase on Mageia for python3 support
